@@ -143,17 +143,27 @@ def unified_timestamp(date_str):
 			pass
 
 
+def remove_quotes(s):
+	if s is None or len(s) < 2:
+		return s
+	for quote in ('"', "'", ):
+		if s[0] == quote and s[-1] == quote:
+			return s[1:-1]
+	return s
+
+
 # NB In principle NaN cannot be checked by membership.
 # Here all NaN values are actually this one, so _NaN is _NaN,
-# although _NaN != _NaN.
+# although _NaN != _NaN. Ditto Infinity.
 
 _NaN = float('nan')
+_Infinity = float('inf')
 
 
 def _js_bit_op(op):
 
 	def zeroise(x):
-		return 0 if x in (None, JSUndefined, _NaN) else x
+		return 0 if x in (None, JSUndefined, _NaN, _Infinity) else x
 
 	def wrapped(a, b):
 		return op(zeroise(a), zeroise(b)) & 0xffffffff
@@ -174,7 +184,7 @@ def _js_arith_op(op):
 def _js_div(a, b):
 	if JSUndefined in (a, b) or not (a or b):
 		return _NaN
-	return operator.truediv(a or 0, b) if b else float('inf')
+	return operator.truediv(a or 0, b) if b else _Infinity
 
 
 def _js_mod(a, b):
@@ -290,13 +300,31 @@ class LocalNameSpace(compat_map):
 		except KeyError:
 			return JSUndefined
 
+	def __setitem__(self, key, value):
+		for scope in self.maps:
+			if key in scope:
+				scope[key] = value
+				return
+		self.maps[0][key] = value
+
 
 class JSInterpreter(object):
 	__named_object_counter = 0
 
+	OP_CHARS = None
+
 	def __init__(self, code, objects=None):
 		self.code, self._functions = code, {}
 		self._objects = {} if objects is None else objects
+		if type(self).OP_CHARS is None:
+			type(self).OP_CHARS = self.OP_CHARS = self.__op_chars()
+
+	@classmethod
+	def __op_chars(cls):
+		op_chars = set(';,[')
+		for op in cls._all_operators():
+			op_chars.update(op[0])
+		return op_chars
 
 	def _named_object(self, namespace, obj):
 		self.__named_object_counter += 1
@@ -306,15 +334,12 @@ class JSInterpreter(object):
 
 	@classmethod
 	def _separate(cls, expr, delim=',', max_split=None, skip_delims=None):
-		OP_CHARS = '+-*/%&|^=<>!,;{}:['
 		if not expr:
 			return
 		# collections.Counter() is ~10% slower in both 2.7 and 3.9
 		counters = {k: 0 for k in _MATCHING_PARENS.values()}
 		start, splits, pos, delim_len = 0, 0, 0, len(delim) - 1
-		in_quote, escaping = None, False
-		after_op, in_regex_char_group = True, False
-
+		in_quote, escaping, after_op, in_regex_char_group = None, False, True, False
 		for idx, char in enumerate(expr):
 			paren_delta = 0
 			if not in_quote:
@@ -332,7 +357,7 @@ class JSInterpreter(object):
 					in_regex_char_group = char == '['
 			escaping = not escaping and in_quote and char == '\\'
 			in_unary_op = (not in_quote and not in_regex_char_group and after_op not in (True, False) and char in '-+')
-			after_op = not in_quote and (char in OP_CHARS or paren_delta > 0 or (after_op and char.isspace()))
+			after_op = not in_quote and (char in cls.OP_CHARS or paren_delta > 0 or (after_op and char.isspace()))
 
 			if char != delim[pos] or any(counters.values()) or in_quote or in_unary_op:
 				pos = 0
@@ -358,10 +383,12 @@ class JSInterpreter(object):
 		return separated[0][1:].strip(), separated[1].strip()
 
 	@staticmethod
-	def _all_operators():
-		return chain(
-			# Ref: https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Operators/Operator_Precedence
-			_SC_OPERATORS, _LOG_OPERATORS, _COMP_OPERATORS, _OPERATORS)
+	def _all_operators(_cached=[]):
+		if not _cached:
+			_cached.extend(chain(
+				# Ref: https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Operators/Operator_Precedence
+				_SC_OPERATORS, _LOG_OPERATORS, _COMP_OPERATORS, _OPERATORS))
+		return _cached
 
 	def _operator(self, op, left_val, right_expr, local_vars, allow_recursion):
 		if op in ('||', '&&'):
@@ -480,7 +507,6 @@ class JSInterpreter(object):
 				expr = self._dump(inner, local_vars) + outer
 
 		if expr.startswith('('):
-
 			m = re.match(r'\((?P<d>[a-z])%(?P<e>[a-z])\.length\+(?P=e)\.length\)%(?P=e)\.length', expr)
 			if m:
 				# short-cut eval of frequently used `(d%e.length+e.length)%e.length`, worth ~6% on `pytest -k test_nsig`
@@ -536,8 +562,7 @@ class JSInterpreter(object):
 					if m.group('err'):
 						catch_vars[m.group('err')] = err
 					catch_vars = local_vars.new_child(m=catch_vars)
-					err = None
-					pending = self.interpret_statement(sub_expr, catch_vars, allow_recursion)
+					err, pending = None, self.interpret_statement(sub_expr, catch_vars, allow_recursion)
 
 			m = self._FINALLY_RE.match(expr)
 			if m:
@@ -640,7 +665,7 @@ class JSInterpreter(object):
 				(?P<op>{_OPERATOR_RE})?
 				=(?!=)(?P<expr>.*)$
 			)|(?P<return>
-				(?!if|return|true|false|null|undefined)(?P<name>{_NAME_RE})$
+				(?!if|return|true|false|null|undefined|NaN|Infinity)(?P<name>{_NAME_RE})$
 			)|(?P<indexing>
 				(?P<in>{_NAME_RE})\[(?P<idx>.+)\]$
 			)|(?P<attribute>
@@ -679,6 +704,8 @@ class JSInterpreter(object):
 			return JSUndefined, should_return
 		elif expr == 'NaN':
 			return _NaN, should_return
+		elif expr == 'Infinity':
+			return _Infinity, should_return
 
 		elif md.get('return'):
 			return local_vars[m.group('name')], should_return
@@ -707,18 +734,31 @@ class JSInterpreter(object):
 			right_expr = separated.pop()
 			# handle operators that are both unary and binary, minimal BODMAS
 			if op in ('+', '-'):
+				# simplify/adjust consecutive instances of these operators
 				undone = 0
-				while len(separated) > 1 and not separated[-1].strip():
+				separated = [s.strip() for s in separated]
+				while len(separated) > 1 and not separated[-1]:
 					undone += 1
 					separated.pop()
 				if op == '-' and undone % 2 != 0:
 					right_expr = op + right_expr
-				left_val = separated[-1]
+				elif op == '+':
+					while len(separated) > 1 and set(separated[-1]) <= self.OP_CHARS:
+						right_expr = separated.pop() + right_expr
+					if separated[-1][-1:] in self.OP_CHARS:
+						right_expr = separated.pop() + right_expr
+				# hanging op at end of left => unary + (strip) or - (push right)
+				left_val = separated[-1] if separated else ''
 				for dm_op in ('*', '%', '/', '**'):
 					bodmas = tuple(self._separate(left_val, dm_op, skip_delims=skip_delim))
 					if len(bodmas) > 1 and not bodmas[-1].strip():
 						expr = op.join(separated) + op + right_expr
-						right_expr = None
+						if len(separated) > 1:
+							separated.pop()
+							right_expr = op.join((left_val, right_expr))
+						else:
+							separated = [op.join((left_val, right_expr))]
+							right_expr = None
 						break
 				if right_expr is None:
 					continue
@@ -736,16 +776,39 @@ class JSInterpreter(object):
 			else:
 				arg_str, remaining = None, arg_str
 
-			def eval_method():
+			def assertion(cndn, msg):
+				""" assert, but without risk of getting optimized out """
+				if not cndn:
+					raise RuntimeError('{0} {1}'.format(member, msg))
+
+			def eval_method(variable, member):
 				if (variable, member) == ('console', 'debug'):
 					return
+
+				ARG_MSG = 'takes one or more arguments'
+				ARG_ONE_MSG = 'takes exactly one argument'
+				ARG_TWO_MSG = 'takes two arguments'
+				ARG_NOT_MSG = 'does not take any arguments'
+				ARG_2_MSG = 'takes at-most 2 arguments'
+				LIST_MSG = 'must be applied on a list'
+
 				types = {
 					'String': compat_str,
 					'Math': float,
+					'Array': list,
 				}
+
 				obj = local_vars.get(variable)
 				if obj in (JSUndefined, None):
 					obj = types.get(variable, JSUndefined)
+				if obj is JSUndefined:
+					try:
+						if variable not in self._objects:
+							self._objects[variable] = self.extract_object(variable)
+						obj = self._objects[variable]
+					except Exception:
+						if not nullish:
+							raise
 
 				if nullish and obj is JSUndefined:
 					return JSUndefined
@@ -759,71 +822,113 @@ class JSInterpreter(object):
 					self.interpret_expression(v, local_vars, allow_recursion)
 					for v in self._separate(arg_str)]
 
-				if obj == compat_str:
+				# Fixup prototype call
+				if isinstance(obj, type):
+					new_member, rest = member.partition('.')[0::2]
+					if new_member == 'prototype':
+						new_member, func_prototype = rest.partition('.')[0::2]
+						assertion(argvals, ARG_MSG)
+						assertion(isinstance(argvals[0], obj), 'must bind to type {0}'.format(obj))
+						if func_prototype == 'call':
+							obj = argvals.pop(0)
+						elif func_prototype == 'apply':
+							assertion(len(argvals) == 2, ARG_TWO_MSG)
+							obj, argvals = argvals
+							assertion(isinstance(argvals, list), 'second argument must be a list')
+						else:
+							raise RuntimeError('Unsupported function method ' + func_prototype)
+						member = new_member
+
+				if obj is compat_str:
 					if member == 'fromCharCode':
+						assertion(argvals, ARG_MSG)
 						return ''.join(map(compat_chr, argvals))
 					raise RuntimeError('Unsupported string method', member)
-				elif obj == float:
+				elif obj is float:
 					if member == 'pow':
+						assertion(len(argvals) == 2, ARG_TWO_MSG)
 						return argvals[0] ** argvals[1]
 					raise RuntimeError('Unsupported Math method', member)
 
 				if member == 'split':
+					assertion(len(argvals) == 1, 'with limit argument is not implemented')
 					return obj.split(argvals[0]) if argvals[0] else list(obj)
 				elif member == 'join':
+					assertion(isinstance(obj, list), LIST_MSG)
+					assertion(len(argvals) == 1, ARG_ONE_MSG)
 					return argvals[0].join(obj)
 				elif member == 'reverse':
+					assertion(not argvals, ARG_NOT_MSG)
 					obj.reverse()
 					return obj
 				elif member == 'slice':
+					assertion(isinstance(obj, list), LIST_MSG)
+					assertion(len(argvals) == 1, ARG_ONE_MSG)
 					return obj[argvals[0]:]
 				elif member == 'splice':
+					assertion(isinstance(obj, list), LIST_MSG)
+					assertion(argvals, ARG_MSG)
 					index, how_many = map(int, (argvals + [len(obj)])[:2])
 					if index < 0:
 						index += len(obj)
 					add_items = argvals[2:]
 					res = []
-					for i in range(index, min(index + how_many, len(obj))):
+					for _ in range(index, min(index + how_many, len(obj))):
 						res.append(obj.pop(index))
 					for i, item in enumerate(add_items):
 						obj.insert(index + i, item)
 					return res
 				elif member == 'unshift':
+					assertion(isinstance(obj, list), LIST_MSG)
+					assertion(argvals, ARG_MSG)
 					for item in reversed(argvals):
 						obj.insert(0, item)
 					return obj
 				elif member == 'pop':
+					assertion(isinstance(obj, list), LIST_MSG)
+					assertion(not argvals, ARG_NOT_MSG)
 					if not obj:
 						return
 					return obj.pop()
 				elif member == 'push':
+					assertion(argvals, ARG_MSG)
 					obj.extend(argvals)
 					return obj
 				elif member == 'forEach':
+					assertion(argvals, ARG_MSG)
+					assertion(len(argvals) <= 2, ARG_2_MSG)
 					f, this = (argvals + [''])[:2]
 					return [f((item, idx, obj), {'this': this}, allow_recursion) for idx, item in enumerate(obj)]
 				elif member == 'indexOf':
+					assertion(argvals, ARG_MSG)
+					assertion(len(argvals) <= 2, ARG_2_MSG)
 					idx, start = (argvals + [0])[:2]
 					try:
 						return obj.index(idx, start)
 					except ValueError:
 						return -1
+				elif member == 'charCodeAt':
+					assertion(isinstance(obj, str), 'must be applied on a string')
+					assertion(len(argvals) == 1, ARG_ONE_MSG)
+					idx = argvals[0] if isinstance(argvals[0], int) else 0
+					if idx >= len(obj):
+						return None
+					return ord(obj[idx])
 
 				idx = int(member) if isinstance(obj, list) else member
 				return obj[idx](argvals, allow_recursion=allow_recursion)
 
 			if remaining:
 				ret, should_abort = self.interpret_statement(
-					self._named_object(local_vars, eval_method()) + remaining,
+					self._named_object(local_vars, eval_method(variable, member)) + remaining,
 					local_vars, allow_recursion)
 				return ret, should_return or should_abort
 			else:
-				return eval_method(), should_return
+				return eval_method(variable, member), should_return
 
 		elif md.get('function'):
 			fname = m.group('fname')
-			argvals = [self.interpret_expression(v, local_vars, allow_recursion)
-				for v in self._separate(m.group('args'))]
+			argvals = [self.interpret_expression(v, local_vars, allow_recursion) for v in self._separate(m.group('args'))]
 			if fname in local_vars:
 				return local_vars[fname](argvals, allow_recursion=allow_recursion), should_return
 			elif fname not in self._functions:
@@ -838,6 +943,33 @@ class JSInterpreter(object):
 			raise RuntimeError('Cannot return from an expression')
 		return ret
 
+	def extract_object(self, objname):
+		_FUNC_NAME_RE = r'''(?:[a-zA-Z$0-9]+|"[a-zA-Z$0-9]+"|'[a-zA-Z$0-9]+')'''
+		obj = {}
+		fields = None
+		for obj_m in re.finditer(
+			r'''(?xs)
+				{0}\s*\.\s*{1}|{1}\s*=\s*\{{\s*
+				(?P<fields>({2}\s*:\s*function\s*\(.*?\)\s*\{{.*?}}(?:,\s*)?)*)
+				}}\s*;
+			'''.format(_NAME_RE, re.escape(objname), _FUNC_NAME_RE),
+			self.code):
+			fields = obj_m.group('fields')
+			if fields:
+				break
+		else:
+			raise RuntimeError('Could not find object ' + objname)
+		# Currently, it only supports function definitions
+		for f in re.finditer(
+			r'''(?x)
+				(?P<key>%s)\s*:\s*function\s*\((?P<args>(?:%s|,)*)\){(?P<code>[^}]+)}
+			''' % (_FUNC_NAME_RE, _NAME_RE),
+			fields):
+			argnames = self.build_arglist(f.group('args'))
+			obj[remove_quotes(f.group('key'))] = self.build_function(argnames, f.group('code'))
+
+		return obj
+
 	@staticmethod
 	def _offset_e_by_d(d, e, local_vars):
 		""" Short-cut eval: (d%e.length+e.length)%e.length """
@@ -873,7 +1005,7 @@ class JSInterpreter(object):
 			if mobj is None:
 				break
 			start, body_start = mobj.span()
-			body, remaining = self._separate_at_paren(code[body_start - 1:], '}')
+			body, remaining = self._separate_at_paren(code[body_start - 1:])
 			name = self._named_object(local_vars, self.extract_function_from_code(
 				[x.strip() for x in mobj.group('args').split(',')],
 				body, local_vars, *global_stack))
@@ -898,8 +1030,7 @@ class JSInterpreter(object):
 		argnames = tuple(argnames)
 
 		def resf(args, kwargs={}, allow_recursion=100):
-			global_stack[0].update(
-				compat_zip_longest(argnames, args, fillvalue=None))
+			global_stack[0].update(compat_zip_longest(argnames, args, fillvalue=None))
 			global_stack[0].update(kwargs)
 			var_stack = LocalNameSpace(*global_stack)
 			ret, should_abort = self.interpret_statement(code.replace('\n', ' '), var_stack, allow_recursion - 1)
